goldilocks package
==================

Submodules
----------

goldilocks.goldilocks module
----------------------------

.. automodule:: goldilocks.goldilocks
    :members:
    :undoc-members:
    :show-inheritance:

goldilocks.strategies module
----------------------------

.. automodule:: goldilocks.strategies
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: goldilocks
    :members:
    :undoc-members:
    :show-inheritance:
